betty.extension.deriver package - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.deriver package

## Module contents

Expand an ancestry by deriving additional data from existing data.

class betty.extension.deriver.Deriver

  Bases: `UserFacingExtension`, `PostLoader`

  Expand an ancestry by deriving additional data from existing data.

  Parameters:

    - app (`betty.app.App`)

    - args (`typing.Any`)

    - kwargs (`typing.Any`)

  classmethod comes_before() → set[type[betty.app.extension.Extension]]

    The extensions that this one comes before.

    The other extensions may or may not be enabled.

    Return type:

      `set`[`type`[`betty.app.extension.Extension`]]

  classmethod description() → betty.locale.Localizable

    Get the human-readable extension description.

    Return type:

      `betty.locale.Localizable`

  classmethod label() → betty.locale.Localizable

    Get the human-readable extension label.

    Return type:

      `betty.locale.Localizable`

  classmethod name() → str

    The machine name.

    Return type:

      `str`

  async post_load() → None

    Act on the ancestry having been loaded.

    This method is called immediately after `betty.load.Loader.load()`.

    Return type:

      `None`